read_words

Function read_words 

pub fn read_words<W, const N: usize>(src: &[u8]) -> [W; N]
where W: Word,
Reads an array of words from a byte slice

Words are read from src in order, using LE conversion from bytes.

Panics

Panics if size_of_val(src) != size_of::<[W; N]>().